@@ -1,4 +1,3 @@
-#! still in development, andy south 11/11/09
 mapBubbles <- function( dF=""
                           ,nameX="longitude"
                           ,nameY="latitude"
@@ -16,6 +15,8 @@ mapBubbles <- function( dF=""
                          , catMethod="categorical"   
                          , colourPalette= "heat" 
                          
+                         , xlim =              NA
+                         , ylim =              NA
                          , mapRegion = "world"   #sets map extents, overrides we,ea etc.                                                    
                          , borderCol = "grey"
                          , oceanCol=NA
@@ -36,7 +37,9 @@ mapBubbles <- function( dF=""
                           ,colourLegendTitle = nameZColour                          
                                                     
                           ,add=FALSE
-                          ,plotZeroVals=TRUE
+                          ,plotZeroVals=TRUE    
+                          ,lwd = 0.5
+                          ,lwdSymbols = 1
                           ,... ) #any extra arguments to points
 {
 
@@ -49,37 +52,44 @@ if ( class(dF)=="character" && dF=="" )
     dF=getMap()@data
     nameX="LON"
     nameY="LAT"
-    nameZSize="POP_EST"
-    nameZColour="GEO3"
+    if (nameZSize=="") nameZSize="POP_EST"
+    if (nameZColour=="") nameZColour="continent"
    }
 
 #allows just a sPDF to be passed and it will get the label points, so doesn't need nameX & nameY to be specified
 if (class(dF)=="SpatialPolygonsDataFrame")
    {
-    if (!add) 
-      {
-        #use passed sPDF as the background map
-        rwmNewMapPlot(mapToPlot=dF,oceanCol=oceanCol,mapRegion=mapRegion)
-        plot( dF, add=TRUE, border=borderCol, col=landCol )
-      }
+    #10/10/12 moved plotting to after getting & setting centroids
   
     #22/4/10 changing this to get centroid coords from the spdf
     centroidCoords <- coordinates(dF)    
     
-    #within this function just need the dF bit of the sPDF
-    dF <- dF@data
+
     #adding extra attribute columns to contain centroids (even though such columns may already be there)
     dF[['nameX']] <- centroidCoords[,1]
     dF[['nameY']] <- centroidCoords[,2]    
     nameX <- 'nameX'
-    nameY <- 'nameY'  
+    nameY <- 'nameY'
+    
+    if (!add) 
+    {
+      #use passed sPDF as the background map
+      rwmNewMapPlot(mapToPlot=dF,oceanCol=oceanCol,mapRegion=mapRegion, xlim=xlim, ylim=ylim)
+      #22/10/12 added main=main but doesn't work
+      plot( dF, add=TRUE, border=borderCol, col=landCol, main=main, lwd=lwd )
+    }
+    
+    #within this function just need the dF bit of the sPDF
+    dF <- dF@data
+    
    } else if (!add) 
    {
     #background map
     #these set the most common params, if user wanted finer control over map
     #they can call rwmNewMapPlot, and then call mapBubbles with add=TRUE     
-    rwmNewMapPlot(mapToPlot=getMap(),oceanCol=oceanCol,mapRegion=mapRegion)
-    plot( getMap(), add=TRUE, border=borderCol, col=landCol )
+    rwmNewMapPlot(mapToPlot=getMap(),oceanCol=oceanCol,mapRegion=mapRegion, xlim=xlim, ylim=ylim)
+    #22/10/12 added main=main but doesn't work
+    plot( getMap(), add=TRUE, border=borderCol, col=landCol, main=main, lwd=lwd )
    }
 
 #a bunch of code here that is repeated from mapCountryData
@@ -94,8 +104,8 @@ if (class(dF)=="SpatialPolygonsDataFrame")
 ## check that the column name exists in the data frame
 singleColour<-FALSE
 if (nameZColour == "") nameZColour <- 'red' #setting colour to red as default
-if ( is.na(match(nameZColour, names(dF)) )){
-  
+if ( is.na(match(nameZColour, names(dF)) ))
+{  
   #now test whether it is a colour
   if ( is.na(match(nameZColour, colours()) ))
      {  
@@ -206,7 +216,7 @@ fMult = symbolSize * 4 / sqrt(maxZVal)
 cex= fMult*sqrt(dF[,nameZSize])
 
 #plotting the symbols
-points( dF[,nameX], dF[,nameY],pch=pch,cex=cex,col=col,bg=bg,... )#, 
+points( dF[,nameX], dF[,nameY], pch=pch, cex=cex, col=col, bg=bg, lwd=lwdSymbols )#, 
 
 
 #points( dF[,nameX], dF[,nameY], cex= fMult*sqrt(dF[,nameZ]) )#, col=dF[,nameZCategory], ... ) #@@@
