@@ -14,7 +14,8 @@ mapCountryData <- function(
               , aspect =            1
               , missingCountryCol = NA
               , add =               FALSE
-              , nameColumnToHatch = ""                                               
+              , nameColumnToHatch = ""    
+              , lwd =               0.5  
               ){
                            
   functionName <- as.character(sys.call()[[1]])
@@ -25,26 +26,37 @@ mapCountryData <- function(
   #added usePolypath=FALSE in plot calls because safer and should work now
   #set_Polypath(FALSE)
   
-  require(sp)
 
- 
- if ( class(mapToPlot)=="SpatialPolygonsDataFrame" ) {
-    ## checking if there is any data in the dataFrame
-    if ( length(mapToPlot@data[,1]) < 1 ){
-      stop("seems to be no data in your chosen file or dataframe in ",functionName) 
-      return(FALSE)
+  #28/6/2013 refactoring
+  new <- TRUE
+  if (new)
+  {
+    #mapToPlot <- rwmCheckAndLoadInput( mapToPlot, requireSPDF = TRUE, callingFunction=functionName )    
+    mapToPlot <- rwmCheckAndLoadInput( mapToPlot, inputNeeded="sPDF", callingFunction=functionName )  
+  } else
+  {
+    if ( class(mapToPlot)=="SpatialPolygonsDataFrame" ) {
+      ## checking if there is any data in the dataFrame
+      if ( length(mapToPlot@data[,1]) < 1 ){
+        stop("seems to be no data in your chosen file or dataframe in ",functionName) 
+        return(FALSE)
+      } 
+    } else if ( mapToPlot == "" ) {
+      message(paste("using example data because no file specified in",functionName))
+      mapToPlot <- getMap(resolution="coarse")
+      
+      ## also setting a default nameColumnToPlot if it isn't set
+      if ( nameColumnToPlot == "" ) nameColumnToPlot <- "POP_EST" #
+    } else {
+      stop(functionName," requires a SpatialPolygonsDataFrame object created by the joinCountryData2Map() function \n")
+      return(FALSE) 
     } 
-  } else if ( mapToPlot == "" ) {
-    message(paste("using example data because no file specified in",functionName))
-    mapToPlot <- getMap(resolution="coarse")
-
-    ## also setting a defsult nameColumnToPlot if it isn't set
-    if ( nameColumnToPlot == "" ) nameColumnToPlot <- "POP_EST" #
-  } else {
-    #warning(inFile," seems not to be a valid file name or data frame, exiting ",functionName,"\n")
-    stop(functionName," requires a SpatialPolygonsDataFrame object created by the joinCountryData2Map() function \n")
-    return(FALSE) 
-  }
+       
+  } #end of replaced bit 28/6/2013
+  
+  ## setting a default nameColumnToPlot if it isn't set
+  # moved out of above loop replaced by rwmCheckAndLoadInput
+  if ( nameColumnToPlot == "" ) nameColumnToPlot <- "POP_EST" #  
   
   ## check that the column name exists in the data frame
   if ( is.na(match(nameColumnToPlot, names(mapToPlot@data)) )){
@@ -67,20 +79,27 @@ mapCountryData <- function(
     { 
       dataCategorised <- as.factor( dataCategorised )
       cutVector <- levels(dataCategorised) #doesn't do cutting but is passed for use in legend
-    }else
-    { 
-      if(is.character(catMethod)==TRUE)
-    	{	
-    		cutVector <- rwmGetClassBreaks( dataCategorised, catMethod=catMethod, numCats=numCats, verbose=TRUE )
-    	} else if(is.numeric(catMethod)==TRUE)
-    	#if catMethod is numeric it is already a vector of breaks	
-    	{
-    		cutVector <- catMethod
-    	}
-  	#Categorising the data, using a vector of breaks.	
-  	dataCategorised <- cut( dataCategorised, cutVector, include.lowest=TRUE)    	
-	  } #end of if data are not categorical
- 
+      numColours <- length(levels(dataCategorised))
+    
+    }else if( is.numeric(catMethod) ) 	 
+    {	
+      #if catMethod is numeric it is already a vector of breaks
+      cutVector <- catMethod
+      #set numColours from the passed breaks
+      numColours <- -1 + length(catMethod)
+      #Categorising the data, using a vector of breaks.	
+      dataCategorised <- cut( dataCategorised, cutVector, include.lowest=TRUE)          
+      
+  	} else if( is.character(catMethod) )
+  	{
+  	  cutVector <- rwmGetClassBreaks( dataCategorised, catMethod=catMethod, numCats=numCats, verbose=TRUE )
+  	  #Categorising the data, using a vector of breaks.	
+  	  dataCategorised <- cut( dataCategorised, cutVector, include.lowest=TRUE)   
+  	  #set numColours from the classified data
+      #numColours <- length(dataCategorised) #!*! BUG 7/11/12
+  	  numColours <- length(levels(dataCategorised))
+  	}
+      
   
   ## add extra column to map attribute data
   colNameRaw <- nameColumnToPlot
@@ -88,7 +107,10 @@ mapCountryData <- function(
   mapToPlot@data[[colNameCat]] <- dataCategorised     
   
   ## how many colours : numCats may be overriden (e.g. for 'pretty') 	
-  numColours <- length(levels(dataCategorised))
+  #5/11/12 issue that numCOlours got from the data
+  #so difficult to keep constant between plots
+  #move it further up so I can control it
+  #numColours <- length(levels(dataCategorised))
   
   ## get vector of the colours to be used in map (length=num categories)    
   colourVector <- rwmGetColours(colourPalette,numColours)
@@ -114,7 +136,7 @@ mapCountryData <- function(
       if (!add) rwmNewMapPlot(mapToPlot,mapRegion=mapRegion,xlim=xlim,ylim=ylim,oceanCol=oceanCol,aspect=aspect)
       #plotting the map
       #plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol,add=TRUE)#,density=c(20:200))#angle=c(1:360),)
-      plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol,add=TRUE,usePolypath=FALSE)#29/9/2012
+      plot(mapToPlot, col=colourVector[dataCatNums], border=borderCol, add=TRUE, usePolypath=FALSE, lwd=lwd)#29/9/2012
       } else  
     {
     #*HATCHING OPTION*
@@ -134,8 +156,8 @@ mapCountryData <- function(
       #plotting the map
       #plot(mapToPlot,col=colourVector[mapToPlot@data$dataCatNums],border=borderCol,add=TRUE, density=hatchVar, angle=135, lty=1)
       #plot(mapToPlot,col=colourVector[mapToPlot@data$dataCatNums],border=borderCol,add=TRUE, density=hatchVar, angle=45, lty=1)
-      plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol, density=hatchVar, angle=135, lty=1,add=TRUE,usePolypath=FALSE)#29/9/2012
-      plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol, density=hatchVar, angle=45, lty=1,add=TRUE,usePolypath=FALSE)#29/9/2012
+      plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol, density=hatchVar, angle=135, lty=1,add=TRUE,usePolypath=FALSE, lwd=lwd)#29/9/2012
+      plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol, density=hatchVar, angle=45, lty=1,add=TRUE,usePolypath=FALSE, lwd=lwd)#29/9/2012
                  
      }  #end of hatching option
 
@@ -143,7 +165,9 @@ mapCountryData <- function(
 
   if (addLegend){
       
-      if((length(catMethod)==1 && catMethod=="categorical") || !require("spam") || !require("fields")){
+      #if((length(catMethod)==1 && catMethod=="categorical") || !require("spam") || !require("fields")){
+      #20/8/13 removed require bits
+			if((length(catMethod)==1 && catMethod=="categorical") ){
       
         # simpler legend for categorical data OR if you don't have packages spam or fields.
         addMapLegendBoxes(colourVector=colourVector,cutVector=cutVector,catMethod=catMethod) #,plottedData=dataCategorised)          
@@ -162,10 +186,7 @@ mapCountryData <- function(
     title( mapTitle )
   }
    
-  ##29/10/09 returning parameter list that can be used by do.call(addMapLegend,*)  
-  #sys.call()[[2]] gets the name of the first argument
-        
-  #invisible(list(plottedData=eval( parse(text=paste(sys.call()[[2]],"[['",nameColumnToPlot,"']]",sep='')))
+  ##returning parameter list that can be used by do.call(addMapLegend,*)  
   invisible(list(colourVector=colourVector
                 ,cutVector=cutVector
                 ,plottedData=mapToPlot[[nameColumnToPlot]]
