@@ -8,12 +8,13 @@ mapGriddedData <- function(
                          , ylim =             c(-80,90) 
                          , mapRegion =        "world"   
                          , addLegend =        TRUE
-                         , addBorders =       'low' 
+                         , addBorders =       'coarse' 
                          , borderCol =        'grey'
                          , oceanCol =         NA
                          , landCol =          NA
                          , plotData =         TRUE
                          , aspect =           1
+                         , lwd =              1  
                          )
    {
 
@@ -22,8 +23,8 @@ mapGriddedData <- function(
 
     functionName <- as.character(sys.call()[[1]])
 
-    require(maptools)
-    require(sp)
+    #require(maptools)
+    #require(sp)
     
     ## filename or nothing ##
     if (class(dataset)=='character')
@@ -158,7 +159,7 @@ mapGriddedData <- function(
     #to fill in any countries with NA values in the grid
     if(!is.na(landCol))
        {
-        plot( getMap(), add=TRUE, border=borderCol, col=landCol )
+        plot( getMap(), add=TRUE, border=borderCol, col=landCol, lwd=lwd )
        }
 
     #only plot ascii data if plotData=T (allows legend to be plotted on its own by setting plotData=F)
@@ -181,18 +182,18 @@ mapGriddedData <- function(
        
     borderOptions = c('low','coarse','coasts',NA,'','none')
     if (addBorders=='low'){
-       plot( getMap(resolution='low'), add=TRUE, border=borderCol )
+       plot( getMap(resolution='low'), add=TRUE, border=borderCol, lwd=lwd )
        } else
     if (addBorders=='coarse'){
-       plot( getMap(resolution='coarse'), add=TRUE, border=borderCol )
+       plot( getMap(resolution='coarse'), add=TRUE, border=borderCol, lwd=lwd )
        } else
     if (addBorders=='coasts'){
        #30/9/2012 replacing use of maps library
        #library(maps) 
        #map(interior=FALSE,add=TRUE, col=borderCol )
-       coastsCoarse <- NULL #to avoid build warning
-       data(coastsCoarse)
-       plot(coastsCoarse, add=TRUE, col=borderCol) 
+       data(coastsCoarse,envir=environment(),package="rworldmap")
+       coastsCoarse <- get("coastsCoarse")
+       plot(coastsCoarse, add=TRUE, col=borderCol, lwd=lwd ) 
        } else 
     if ( ! addBorders %in% borderOptions){
        warning("unrecognised addBorders = ",addBorders, "none plotted, choose one of",paste(borderOptions,""))
@@ -201,8 +202,9 @@ mapGriddedData <- function(
     ## adding a default legend, can be modified by calling addMapLegend() independently  
     if (addLegend){
     
-      ## simpler legend for categorical data OR if you don't have packages spam or fields.
-      if((length(catMethod)==1 && catMethod=="categorical") || !require("spam") || !require("fields")){
+      #if((length(catMethod)==1 && catMethod=="categorical") || !require("spam") || !require("fields")){
+      #20/8/13 removed require bits
+			if((length(catMethod)==1 && catMethod=="categorical") ){
         
         #legend(x='bottomleft', legend=c(rev(levels(dataCategorised)),"no data"), pch = 22, pt.cex=2, col=borderCol,pt.bg=c(coloursForMap[numColours:1],"white"), title="category",bg="white" )
         addMapLegendBoxes(colourVector=colourVector,cutVector=cutVector,plottedData=dataCategorised,catMethod=catMethod)          
