@@ -21,34 +21,46 @@ mapPolys <- function(
                            oceanCol=NA,
                            aspect=1,
                            missingCountryCol=NA,
-                           add=FALSE                                                    
+                           add=FALSE, 
+                           lwd=0.5
                            ){
                            
   functionName <- as.character(sys.call()[[1]])
                            
   #browser()  #n to enter the step through debugger, Q to exit
   
-  require(sp)
- 
- if ( class(mapToPlot)=="SpatialPolygonsDataFrame" ) {
-    ## checking if there is any data in the dataFrame
-    if ( length(mapToPlot@data[,1]) < 1 ){
-      stop("seems to be no data in your chosen file or dataframe in ",functionName) 
-      return(FALSE)
-    } 
-  } else if ( mapToPlot == "" ) {
-    message(paste("using example data because no file specified in",functionName))
-    mapToPlot <- getMap(resolution="coarse")
-    #data("countryExData",envir=environment(),package="rworldmap")
-    #dF <- get("countryExData") # copying from the example data
-    ## also setting a defsult nameColumnToPlot if it isn't set
-    if ( nameColumnToPlot == "" ) nameColumnToPlot <- "POP_EST" #
-  } else {
-    #warning(inFile," seems not to be a valid file name or data frame, exiting ",functionName,"\n")
-    stop(functionName," requires a SpatialPolygonsDataFrame object created by the joinCountryData2Map() function \n")
-    return(FALSE) 
-  }
+  #require(sp)
   
+  #28/6/2013 refactoring
+  new <- TRUE
+  if (new)
+  {
+    #mapToPlot <- rwmCheckAndLoadInput( mapToPlot, requireSPDF = TRUE, callingFunction=functionName )    
+    mapToPlot <- rwmCheckAndLoadInput( mapToPlot, inputNeeded="sPDF", callingFunction=functionName )    
+  } else
+  {
+     if ( class(mapToPlot)=="SpatialPolygonsDataFrame" ) {
+        ## checking if there is any data in the dataFrame
+        if ( length(mapToPlot@data[,1]) < 1 ){
+          stop("seems to be no data in your chosen file or dataframe in ",functionName) 
+          return(FALSE)
+        } 
+      } else if ( mapToPlot == "" ) {
+        message(paste("using example data because no file specified in",functionName))
+        mapToPlot <- getMap(resolution="coarse")
+        ## also setting a defsult nameColumnToPlot if it isn't set
+        #if ( nameColumnToPlot == "" ) nameColumnToPlot <- "POP_EST" #
+      } else {
+        stop(functionName," requires a SpatialPolygonsDataFrame object created by the joinCountryData2Map() function \n")
+        return(FALSE) 
+      }
+
+  } #end of replaced bit 28/6/2013
+  
+  ## setting a default nameColumnToPlot if it isn't set
+  # moved out of above loop replaced by rwmCheckAndLoadInput
+  if ( nameColumnToPlot == "" ) nameColumnToPlot <- "POP_EST" #  
+ 
   ## check that the column name exists in the data frame
   if ( is.na(match(nameColumnToPlot, names(mapToPlot@data)) )){
     stop("your chosen nameColumnToPlot :'",nameColumnToPlot,"' seems not to exist in your data, columns = ",paste(names(mapToPlot@data),""))
@@ -111,7 +123,7 @@ mapPolys <- function(
   #setting up the map plot
   if (!add) rwmNewMapPlot(mapToPlot,mapRegion=mapRegion,xlim=xlim,ylim=ylim,oceanCol=oceanCol,aspect=aspect)
   #plotting the map
-  plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol,add=TRUE) #,density=c(20:200))#angle=c(1:360),)
+  plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol,add=TRUE,lwd=lwd) #,density=c(20:200))#angle=c(1:360),)
   
   #trying out shading with density & angle
   #plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol,add=TRUE,density=c(20:200))#angle=c(1:360),)
@@ -120,7 +132,9 @@ mapPolys <- function(
    
   if (addLegend){
       
-      if((length(catMethod)==1 && catMethod=="categorical") || !require("spam") || !require("fields")){
+      #if((length(catMethod)==1 && catMethod=="categorical") || !require("spam") || !require("fields")){
+      #20/8/13 removed require bits
+			if((length(catMethod)==1 && catMethod=="categorical") ){
       
         # simpler legend for categorical data OR if you don't have packages spam or fields.
         addMapLegendBoxes(colourVector=colourVector,cutVector=cutVector,catMethod=catMethod) #,plottedData=dataCategorised)          
